==> swh.storage-0.3.0.tar.gz: swh.storage-0.3.0/setup.py <==
#!/usr/bin/env python3
# Copyright (C) 2015-2018  The Software Heritage developers
# See the AUTHORS file at the top-level directory of this distribution
# License: GNU General Public License version 3, or any later version
# See top-level LICENSE file for more information

from setuptools import setup, find_packages

from os import path
from io import open

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


def parse_requirements(name=None):
    if name:
        reqf = "requirements-%s.txt" % name
    else:
        reqf = "requirements.txt"

    requirements = []
    if not path.exists(reqf):
        return requirements

    with open(reqf) as f:
        for line in f.readlines():
            line = line.strip()
            if not line or line.startswith("#"):
                continue
            requirements.append(line)
    return requirements


setup(
    name="swh.storage",
    description="Software Heritage storage manager",
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3.7",
    author="Software Heritage developers",
    author_email="swh-devel@inria.fr",
    url="https://forge.softwareheritage.org/diffusion/DSTO/",
    packages=find_packages(),
    scripts=["bin/swh-storage-add-dir",],
    entry_points="""
        [console_scripts]
        swh-storage=swh.storage.cli:main
        [swh.cli.subcommands]
        storage=swh.storage.cli:storage
    """,
    setup_requires=["vcversioner"],
    install_requires=parse_requirements() + parse_requirements("swh"),
    extras_require={
        "testing": (parse_requirements("test") + parse_requirements("swh-journal")),
        "schemata": ["SQLAlchemy"],
        "journal": parse_requirements("swh-journal"),
    },
    vcversioner={},
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
    ],
    project_urls={
        "Bug Reports": "https://forge.softwareheritage.org/maniphest",
        "Funding": "https://www.softwareheritage.org/donate",
        "Source": "https://forge.softwareheritage.org/source/swh-storage",
        "Documentation": "https://docs.softwareheritage.org/devel/swh-storage/",
    },
)

==> swh.storage-0.10.6.tar.gz: swh.storage-0.10.6/setup.py <==
#!/usr/bin/env python3
# Copyright (C) 2015-2020  The Software Heritage developers
# See the AUTHORS file at the top-level directory of this distribution
# License: GNU General Public License version 3, or any later version
# See top-level LICENSE file for more information

from setuptools import setup, find_packages

from os import path
from io import open

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


def parse_requirements(name=None):
    if name:
        reqf = "requirements-%s.txt" % name
    else:
        reqf = "requirements.txt"

    requirements = []
    if not path.exists(reqf):
        return requirements

    with open(reqf) as f:
        for line in f.readlines():
            line = line.strip()
            if not line or line.startswith("#"):
                continue
            requirements.append(line)
    return requirements


setup(
    name="swh.storage",
    description="Software Heritage storage manager",
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3.7",
    author="Software Heritage developers",
    author_email="swh-devel@inria.fr",
    url="https://forge.softwareheritage.org/diffusion/DSTO/",
    setup_requires=["setuptools-scm"],
    packages=find_packages(),
    use_scm_version=True,
    scripts=["bin/swh-storage-add-dir",],
    entry_points="""
        [console_scripts]
        swh-storage=swh.storage.cli:main
        [swh.cli.subcommands]
        storage=swh.storage.cli:storage
    """,
    install_requires=parse_requirements() + parse_requirements("swh"),
    extras_require={
        "testing": (parse_requirements("test") + parse_requirements("swh-journal")),
        "schemata": ["SQLAlchemy"],
        "journal": parse_requirements("swh-journal"),
    },
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
    ],
    project_urls={
        "Bug Reports": "https://forge.softwareheritage.org/maniphest",
        "Funding": "https://www.softwareheritage.org/donate",
        "Source": "https://forge.softwareheritage.org/source/swh-storage",
        "Documentation": "https://docs.softwareheritage.org/devel/swh-storage/",
    },
)
